---
title: 해외 카드코드
description: 금융결제원 기관코드가 정의되어 있지 않은 해외 카드사 코드를 확인합니다.
targetVersions:
  - v1
---

|카드코드|카드명          |
|--------|----------------|
|`10001` |해외은련카드    |
|`10002` |해외다이너스카드|
|`10003` |해외아멕스카드  |
|`10004` |해외마스터카스  |
|`10005` |해외비자카드    |
|`10006` |해외JCB카드     |
